@@ -13,7 +13,7 @@ class BookLoadNotification:
                     f'"loadId": "{load_id}", ' \
                     f'"subject" : "{self._app_config.BOOK_LOAD_SNS_SUBJECT}", ' \
                     f'"className":  "{self._app_config.BOOK_LOAD_SNS_CLASS_NAME}"' + '}'
-    logger.debug(f"sending messsage {message} to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}")
+    logger.debug(f"sending BookLoadNotification {message} to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}")
 
     try:
       sns_service = SnsService()
@@ -21,4 +21,3 @@ class BookLoadNotification:
         self._app_config.BOOK_LOAD_SNS_SUBJECT, message)
     except Exception as e:
       logger.exception(f"failed to send message to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}: {message} - {e}", e)
-
